AuthTextStyles class

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

bodyL TextStyle
no setter
bodyM TextStyle
no setter
caption TextStyle
no setter
ctaLabel TextStyle
no setter
headlineM TextStyle
no setter
headlineS TextStyle
no setter
labelM TextStyle
no setter
titleM TextStyle
no setter