ConflictDetector class

Constructors

ConflictDetector({List<String> ignoredFields = const ['updatedAt', 'lastSeen', 'syncVersion', '_localId', 'cachedAt']})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
ignoredFields List<String>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

detectConflicts(Map<String, dynamic> local, Map<String, dynamic> remote) List<String>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited