OfflineSyncLayer class

Properties

config SyncConfig
no setter
connectivityMonitor ConnectivityMonitor
no setter
hashCode int
The hash code for this object.
no setterinherited
isInitialized bool
no setter
isSyncing bool
no setter
metrics SyncMetrics
no setter
queueManager QueueManager
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stateMachine SyncStateMachine
no setter
syncProgress Stream<SyncProgress>
no setter
syncState Stream<SyncStateType>
no setter

Methods

addObserver(SyncObserver observer) → void
clearQueue() Future<void>
dispose() Future<void>
getPendingCount() Future<int>
getPendingOperations() Future<List<Map<String, dynamic>>>
initialize({SyncConfig? config}) Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
registerOperationHandler(String category, Future<void> handler(Map<String, dynamic>)) → void
removeObserver(SyncObserver observer) → void
retryFailedOperation(String id) Future<void>
submitOperation({required String category, required int priority, required Map<String, dynamic> data, String? idempotencyKey}) Future<void>
sync({SyncStrategyType strategy = SyncStrategyType.auto}) Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance OfflineSyncLayer
no setter