SyncConfig class

Constructors

SyncConfig({bool autoSyncOnReconnect = true, bool syncImmediately = true, Duration? autoSyncInterval, int maxRetries = 5, Duration initialRetryDelay = const Duration(seconds: 2), int maxConcurrentOperations = 3, bool enableMetrics = true, bool enableDebugLogging = false, bool syncOnWiFiOnly = false, int maxQueueSize = 1000, ConflictStrategy? conflictStrategy})
const
SyncConfig.aggressive()
factory
SyncConfig.batteryFriendly()
factory
SyncConfig.defaultConfig()
factory
SyncConfig.wifiOnly()
factory

Properties

autoSyncInterval Duration?
final
autoSyncOnReconnect bool
final
conflictStrategy ConflictStrategy?
final
enableDebugLogging bool
final
enableMetrics bool
final
hashCode int
The hash code for this object.
no setterinherited
initialRetryDelay Duration
final
maxConcurrentOperations int
final
maxQueueSize int
final
maxRetries int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
syncImmediately bool
final
syncOnWiFiOnly bool
final

Methods

copyWith({bool? autoSyncOnReconnect, bool? syncImmediately, Duration? autoSyncInterval, int? maxRetries, Duration? initialRetryDelay, int? maxConcurrentOperations, bool? enableMetrics, bool? enableDebugLogging, bool? syncOnWiFiOnly, int? maxQueueSize, ConflictStrategy? conflictStrategy}) SyncConfig
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited